[Fusionforge-commits] r6937 - in trunk/gforge/plugins/wiki/www/lib: . nusoap

Alain Peyrat aljeux at libremir.placard.fr.eu.org
Wed Feb 4 22:27:52 CET 2009


Author: aljeux
Date: 2009-02-04 22:27:51 +0100 (Wed, 04 Feb 2009)
New Revision: 6937

Modified:
   trunk/gforge/plugins/wiki/www/lib/Google.php
   trunk/gforge/plugins/wiki/www/lib/nusoap/README.txt
   trunk/gforge/plugins/wiki/www/lib/nusoap/nusoap.php
Log:
Fix soapclient clash with php5 builtin soapclient (renamed to nusoapclient)

Modified: trunk/gforge/plugins/wiki/www/lib/Google.php
===================================================================
--- trunk/gforge/plugins/wiki/www/lib/Google.php	2009-02-04 21:27:36 UTC (rev 6936)
+++ trunk/gforge/plugins/wiki/www/lib/Google.php	2009-02-04 21:27:51 UTC (rev 6937)
@@ -166,8 +166,8 @@
             $this->license_key = GOOGLE_LICENSE_KEY;
         require_once("lib/nusoap/nusoap.php");
 
-        $this->soapclient = new soapclient(SERVER_URL . NormalizeWebFileName("GoogleSearch.wsdl"), "wsdl");
-        $this->proxy = $this->soapclient->getProxy();
+        $this->nusoapclient = new nusoapclient(SERVER_URL . NormalizeWebFileName("GoogleSearch.wsdl"), "wsdl");
+        $this->proxy = $this->nusoapclient->getProxy();
         if ($maxResults > 10) $maxResults = 10;
         if ($maxResults < 1) $maxResults = 1;
         $this->maxResults = $maxResults;

Modified: trunk/gforge/plugins/wiki/www/lib/nusoap/README.txt
===================================================================
--- trunk/gforge/plugins/wiki/www/lib/nusoap/README.txt	2009-02-04 21:27:36 UTC (rev 6936)
+++ trunk/gforge/plugins/wiki/www/lib/nusoap/README.txt	2009-02-04 21:27:51 UTC (rev 6937)
@@ -68,8 +68,8 @@
 
 require_once('nusoap.php');
 $parameters = array('name'=>'dietrich');
-$soapclient = new soapclient('http://someSOAPServer.com/hello.php');
-echo $soapclient->call('hello',$parameters);
+$nusoapclient = new nusoapclient('http://someSOAPServer.com/hello.php');
+echo $nusoapclient->call('hello',$parameters);
 
 ?>
 
@@ -79,8 +79,8 @@
 
 require_once('nusoap.php');
 $parameters = array('dietrich');
-$soapclient = new soapclient('http://someSOAPServer.com/hello.wsdl','wsdl');
-echo $soapclient->call('hello',$parameters);
+$nusoapclient = new nusoapclient('http://someSOAPServer.com/hello.wsdl','wsdl');
+echo $nusoapclient->call('hello',$parameters);
 
 ?>
 
@@ -89,8 +89,8 @@
 <?php
 
 require_once('nusoap.php');
-$soapclient = new soapclient('http://someSOAPServer.com/hello.wsdl','wsdl');
-$soap_proxy = $soapclient->getProxy();
+$nusoapclient = new nusoapclient('http://someSOAPServer.com/hello.wsdl','wsdl');
+$soap_proxy = $nusoapclient->getProxy();
 echo $soap_proxy->hello('dietrich');
 
 ?>

Modified: trunk/gforge/plugins/wiki/www/lib/nusoap/nusoap.php
===================================================================
--- trunk/gforge/plugins/wiki/www/lib/nusoap/nusoap.php	2009-02-04 21:27:36 UTC (rev 6936)
+++ trunk/gforge/plugins/wiki/www/lib/nusoap/nusoap.php	2009-02-04 21:27:51 UTC (rev 6937)
@@ -36,7 +36,7 @@
 /* load classes
 
 // necessary classes
-require_once('class.soapclient.php');
+require_once('class.nusoapclient.php');
 require_once('class.soap_val.php');
 require_once('class.soap_parser.php');
 require_once('class.soap_fault.php');
@@ -3611,24 +3611,24 @@
 
 /**
 *
 * soapclient higher level class for easy usage.
 *
 * usage:
 *
 * // instantiate client with server info
-* $soapclient = new soapclient( string path [ ,boolean wsdl] );
+* $nusoapclient = new nusoapclient( string path [ ,boolean wsdl] );
 *
 * // call method, get results
-* echo $soapclient->call( string methodname [ ,array parameters] );
+* echo $nusoapclient->call( string methodname [ ,array parameters] );
 *
 * // bye bye client
-* unset($soapclient);
+* unset($nusoapclient);
 *
 * @author   Dietrich Ayala <dietrich at ganx4.com>
 * @version  v 0.6.3
 * @access   public
 */
-class soapclient extends nusoap_base  {
+class nusoapclient extends nusoap_base  {
 
     var $username = '';
     var $password = '';
@@ -3664,7 +3664,7 @@
      * @param	int $portName optional portName in WSDL document
      * @access   public
      */
-    function soapclient($endpoint,$wsdl = false){
+    function nusoapclient($endpoint,$wsdl = false){
         $this->endpoint = $endpoint;
 
         // make values
@@ -4057,7 +4057,7 @@
                 }
             }
             $r = rand();
-            $evalStr = 'class soap_proxy_'.$r.' extends soapclient {
+            $evalStr = 'class soap_proxy_'.$r.' extends nusoapclient {
 				'.$evalStr.'
 			}';
             //print "proxy class:<pre>$evalStr</pre>";
@@ -3611,24 +3611,24 @@
 /**
 *
-* soapclient higher level class for easy usage.
+* nusoapclient higher level class for easy usage.
 *
 * usage:




More information about the Fusionforge-commits mailing list